Glossary
========

Terminology
-----------

.. glossary::

    detector
        a piece of hardware that changes incident photons to signal, can consist of several sensitive segments or channels (e.g. photodiode array) \\
    pixel
    channel
        one sensitive unit in detector, one unit in recorded signal
    reconstruction plane 
        a plane that is either observed by detectors or lines of sights are transformed to it, usually poloidal cut is used for tokamaks
    node
    voxel
        one segment in reconstruction plane described by a local basis function
    camera
        enclosure for detector defining view and ensuring survival of detector (shielding, cooling...)
    line of sight
    chord
        line approximating area that given detector channel can observe

Shortcuts
---------

.. glossary::

    MFR
        Minimum Fisher Regularisation
    LAME
        Linear Algebraic Methods
    BOB
        Biorthogonal Basis Decomposition